import babel from 'rollup-plugin-babel';
import resolve from '@rollup/plugin-node-resolve';
import external from 'rollup-plugin-peer-deps-external';
import { terser } from 'rollup-plugin-terser';
import replace from '@rollup/plugin-replace';
import commonjs from '@rollup/plugin-commonjs';

import postcss from 'rollup-plugin-postcss';

import React from 'react';
import ReactDOM from 'react-dom';

export default [
    {
        input: './src/index.js',
        output: [
            {
                file: 'dist/index.js',
                format: 'cjs',
                sourcemap: true
            },
            {
                file: 'dist/index.es.js',
                format: 'esm',
                sourcemap: true,
                exports: 'named'
            }
        ],
        plugins: [
            replace({
                "process.env.NODE_ENV": JSON.stringify("development")
            }),
            commonjs({
                include: /node_modules/,
                namedExports: {
                    'react': Object.keys(React),
                    'react-dom': Object.keys(ReactDOM)
                }
            }),
            postcss({
                extensions: ['.css'],
                plugins: [],
                minimize: true
            }),
            babel({
                exclude: 'node_modules/**',
                presets: [
                    '@babel/preset-react'
                ]
            }),
            external(),
            resolve(),
            terser()
        ]
    }
]